@@ -7,6 +7,11 @@ class DiclosePayload(VariablePayload):
     format_list = ['varlenH', 'varlenH', 'varlenH', 'varlenH']
     names = ['metadata', 'tokens', 'attestations', 'authorities']
 
+    metadata: bytes
+    tokens: bytes
+    attestations: bytes
+    authorities: bytes
+
 
 @vp_compile
 class AttestPayload(VariablePayload):
@@ -14,6 +19,8 @@ class AttestPayload(VariablePayload):
     format_list = ['varlenH']
     names = ['attestation']
 
+    attestation: bytes
+
 
 @vp_compile
 class RequestMissingPayload(VariablePayload):
@@ -21,9 +28,13 @@ class RequestMissingPayload(VariablePayload):
     format_list = ['I']
     names = ['known']
 
+    known: int
+
 
 @vp_compile
 class MissingResponsePayload(VariablePayload):
     msg_id = 4
     format_list = ['raw']
     names = ['tokens']
+
+    tokens: bytes
