@@ -1,11 +1,13 @@
 from __future__ import annotations
 
+import base64
 import copy
 import enum
-import socket
 import typing
 from typing import Any, Dict
 
+from .keyvault.crypto import default_eccrypto
+
 DISPERSY_BOOTSTRAPPER: Dict[Any, Any] = {
     'class': "DispersyBootstrapper",
     'init': {
@@ -43,8 +45,13 @@ DISPERSY_BOOTSTRAPPER: Dict[Any, Any] = {
 }
 
 default = {
-    'address': '0.0.0.0',
-    'port': 8090,
+    'interfaces': [
+        {
+            'interface': "UDPIPv4",
+            'ip': "0.0.0.0",
+            'port': 8090
+        }
+    ],
     'keys': [
         {
             'alias': "anonymous id",
@@ -193,16 +200,12 @@ class ConfigBuilder(object):
         Essentially this only checks the `config` variable for errors, use that instead if you're confident you never
         make any errors.
         """
-        assert self.config.get('address') is not None, "Missing address in config!"
-        assert self.config.get('port') is not None, "Missing port in config!"
         assert self.config.get('keys') is not None, "Missing keys in config!"
         assert self.config.get('logger') is not None, "Missing logger in config!"
         assert self.config.get('walker_interval') is not None, "Missing walker_interval in config!"
         assert self.config.get('overlays') is not None, "Missing overlays in config!"
         assert self.config.get('working_directory') is not None, "Missing working_directory in config!"
 
-        socket.inet_aton(self.config.get('address'))  # Errors out if the address is illegal
-        assert 0 <= self.config['port'] <= 65535
         assert self.config['walker_interval'] >= 0
 
         for overlay in self.config['overlays']:
@@ -227,10 +230,6 @@ class ConfigBuilder(object):
                     f"Missing peers in {walker['strategy']} config of {overlay['class']}!"
                 assert walker.get('init') is not None,\
                     f"Missing init in {walker['strategy']} config of {overlay['class']}!"
-                assert walker['strategy'] in Strategy.values()
-                if (walker['strategy'] == Strategy.RandomChurn.value
-                        or walker['strategy'] == Strategy.PeriodicSimilarity.value):
-                    assert overlay['class'] == 'DiscoveryCommunity'
             for bootstrapper in overlay['bootstrappers']:
                 assert bootstrapper.get('class') is not None,\
                     f"Missing bootstrapper class in bootstrapper config of {overlay['class']}!"
@@ -254,23 +253,46 @@ class ConfigBuilder(object):
         self.config['overlays'] = []
         return self
 
-    def set_address(self, address: str) -> ConfigBuilder:
+    def set_address(self, address: str, interface: str = "UDPIPv4") -> ConfigBuilder:
         """
         Set the address IPv8 is to try and bind to.
 
-        For localhost only use: 127.0.0.1
-        For Internet communication use: 0.0.0.0
+        | For IPv4 localhost only use ``127.0.0.1``
+        | For IPv4 Internet communication use ``0.0.0.0``
+        | For IPv6 localhost only use ``::1``
+        | For IPv6 Internet communication use ``::``
+
+        :param address: the address to attempt to bind to.
+        :param interface: the interface to use (currently "UDPIPv4" or "UDPIPv6").
         """
-        assert address.count('.') == 3
-        self.config['address'] = address
+        existing = ([spec for spec in self.config['interfaces'] if spec['interface'] == interface]
+                    if 'interfaces' in self.config else [])
+        destination = existing[0] if existing else {'interface': interface}
+        destination['ip'] = address
+        if not existing:
+            if 'interfaces' in self.config:
+                self.config['interfaces'].append(destination)
+            else:
+                self.config['interfaces'] = [destination]
         return self
 
-    def set_port(self, port: int) -> ConfigBuilder:
+    def set_port(self, port: int, interface: str = "UDPIPv4") -> ConfigBuilder:
         """
         Set the port that IPv8 should TRY to bind to.
         If your port is not available, IPv8 will try and find another one.
+
+        :param port: the port to attempt to bind to.
+        :param interface: the interface to use (currently "UDPIPv4" or "UDPIPv6").
         """
-        self.config['port'] = port
+        existing = ([spec for spec in self.config['interfaces'] if spec['interface'] == interface]
+                    if 'interfaces' in self.config else [])
+        destination = existing[0] if existing else {'interface': interface}
+        destination['port'] = port
+        if not existing:
+            if 'interfaces' in self.config:
+                self.config['interfaces'].append(destination)
+            else:
+                self.config['interfaces'] = [destination]
         return self
 
     def set_log_level(self, log_level: str) -> ConfigBuilder:
@@ -320,6 +342,38 @@ class ConfigBuilder(object):
         })
         return self
 
+    def add_key_from_bin(self, alias: str, key_bin_b64: str, file_path: typing.Optional[str] = None) -> ConfigBuilder:
+        """
+        Add a key by alias and  its raw key material, possibly stored at a certain file path.
+
+        If a key already exists at the given file path, that will be loaded instead of the given key material.
+
+        :param alias: the alias used to reference this key
+        :param key_bin_b64: the base64 encoded private key material
+        :param file_path: the optional file path to save the key to
+        """
+        if 'keys' in self.config:
+            self.config['keys'] = [key for key in self.config['keys'] if key['alias'] != alias]
+        else:
+            self.config['keys'] = []
+        key_config = {
+            'alias': alias,
+            'bin': key_bin_b64
+        }
+        if file_path is not None:
+            key_config['file'] = file_path
+        self.config['keys'].append(key_config)
+        return self
+
+    def add_ephemeral_key(self, alias: str) -> ConfigBuilder:
+        """
+        Add an ephemeral key, which is only stored in memory (i.e., not associated with a file).
+
+        :param alias: the alias used to reference this key
+        """
+        eph_key = default_eccrypto.generate_key("curve25519").key_to_bin()
+        return self.add_key_from_bin(alias, base64.b64encode(eph_key).decode(), "")
+
     def add_overlay(self,
                     overlay_class: str,
                     key_alias: str,
