@@ -8,7 +8,7 @@ import os
 import random
 import socket
 import struct
-from asyncio import gather, iscoroutine
+from asyncio import CancelledError, gather, iscoroutine
 
 from .caches import *
 from .community import TunnelCommunity, unpack_cell
@@ -22,6 +22,7 @@ from ...configuration import DISPERSY_BOOTSTRAPPER
 from ...keyvault.public.libnaclkey import LibNaCLPK
 from ...messaging.anonymization.pex import PexCommunity
 from ...peer import Peer
+from ...peerdiscovery.churn import RandomChurn
 from ...peerdiscovery.discovery import RandomWalk
 from ...peerdiscovery.network import Network
 from ...taskmanager import task
@@ -90,20 +91,19 @@ class HiddenTunnelCommunity(TunnelCommunity):
         :param info_hash: the swarm identifier
         :type info_hash: bytes
         """
-        self.e2e_callbacks.pop(info_hash, None)
+        # Remove all introduction points and e2e circuits for this swarm
+        for circuit in self.circuits.values():
+            if circuit.info_hash == info_hash and circuit.ctype in [CIRCUIT_TYPE_IP_SEEDER,
+                                                                    CIRCUIT_TYPE_RP_SEEDER,
+                                                                    CIRCUIT_TYPE_RP_DOWNLOADER]:
+                self.remove_circuit(circuit.circuit_id, 'leaving hidden swarm', destroy=DESTROY_REASON_LEAVE_SWARM)
+        # Remove swarm and callback
         swarm = self.swarms.pop(info_hash, None)
-        if swarm:
-            # If there are no other swarms with the same hop count, remove the data circuits
-            if not [s for s in self.swarms.values() if s != swarm and s.hops == swarm.hops]:
-                for circuit in self.find_circuits(hops=swarm.hops, state=None):
-                    self.remove_circuit(circuit.circuit_id, 'not needed', destroy=DESTROY_REASON_UNNEEDED)
-            # Remove e2e circuits
-            for rp_circuit, _ in swarm.connections.values():
-                self.remove_circuit(rp_circuit.circuit_id, 'leaving hidden swarm', destroy=DESTROY_REASON_LEAVE_SWARM)
-        # Remove introduction points
-        for ip_circuit in self.circuits.values():
-            if ip_circuit.info_hash == info_hash and ip_circuit.ctype == CIRCUIT_TYPE_IP_SEEDER:
-                self.remove_circuit(ip_circuit.circuit_id, 'leaving hidden swarm', destroy=DESTROY_REASON_LEAVE_SWARM)
+        self.e2e_callbacks.pop(info_hash, None)
+        # If there are no other swarms with the same hop count, remove the data circuits
+        if swarm and not [s for s in self.swarms.values() if s != swarm and s.hops == swarm.hops]:
+            for circuit in self.find_circuits(hops=swarm.hops, state=None):
+                self.remove_circuit(circuit.circuit_id, 'not needed', destroy=DESTROY_REASON_UNNEEDED)
 
     async def estimate_swarm_size(self, info_hash, hops=1, max_requests=10):
         """
@@ -116,7 +116,6 @@ class HiddenTunnelCommunity(TunnelCommunity):
         :param max_requests: the number of introduction points we should send a get-peers message to
         :type max_requests: int
         :return: number of unique seeders
-        :rtype: Deferred
         """
         swarm = Swarm(info_hash, hops, self.send_peers_request)
 
@@ -134,7 +133,7 @@ class HiddenTunnelCommunity(TunnelCommunity):
             responses = await gather(*[swarm.lookup(ip) for ip in ips], return_exceptions=True)
 
             # Collect responses
-            all_ += sum([result for result in responses if not isinstance(result, Exception)], [])
+            all_ += sum([result for result in responses if not isinstance(result, (CancelledError, Exception))], [])
             tried |= set(ips)
 
         return len({ip.seeder_pk for ip in all_ if ip and ip.source == PEER_SOURCE_PEX})
@@ -186,7 +185,8 @@ class HiddenTunnelCommunity(TunnelCommunity):
                                  len([ip for ip in ips if ip.source == PEER_SOURCE_PEX]),
                                  binascii.hexlify(info_hash))
                 for ip in set(ips):
-                    ip = swarm.add_intro_point(ip)
+                    swarm.add_intro_point(ip)
+                for ip in swarm.intro_points:
                     if not swarm.has_connection(ip.seeder_pk):
                         self.create_e2e(info_hash, ip)
 
@@ -274,7 +274,7 @@ class HiddenTunnelCommunity(TunnelCommunity):
             return fail(RuntimeError("No circuit for peers-request"))
 
         # Send a peers-request message over this circuit
-        cache = PeersRequestCache(self, circuit, info_hash)
+        cache = PeersRequestCache(self, circuit, info_hash, target)
         self.request_cache.add(cache)
         payload = PeersRequestPayload(circuit.circuit_id, cache.number, info_hash)
 
@@ -308,8 +308,8 @@ class HiddenTunnelCommunity(TunnelCommunity):
             self.logger.warning("Received a peers-request over the socket, but unable to do a PEX lookup")
 
     def send_peers_response(self, target_addr, request, intro_points, circuit_id):
-        peers = [IntroductionInfo(ip.peer.address, ip.peer.public_key.key_to_bin(),
-                                  ip.seeder_pk, ip.source) for ip in intro_points[:7]]
+        peers = [IntroductionInfo(ip.peer.address, ip.peer.public_key.key_to_bin(), ip.seeder_pk, ip.source)
+                 for ip in random.sample(intro_points, min(len(intro_points), 7))]
         payload = PeersResponsePayload(request.circuit_id, request.identifier, request.info_hash, peers)
 
         if circuit_id is not None:
@@ -418,6 +418,7 @@ class HiddenTunnelCommunity(TunnelCommunity):
         relay_circuit = self.rendezvous_point_for[payload.cookie]
         if self.exit_sockets[relay_circuit.circuit_id].enabled:
             self.logger.warning("Exit socket for relay_circuit is enabled, cannot link")
+            return
 
         circuit = self.exit_sockets[circuit_id]
 
@@ -487,6 +488,7 @@ class HiddenTunnelCommunity(TunnelCommunity):
             # Since IPv8 takes a step every .5s until we have 10 peers, the PexCommunity will generate
             # a lot of traffic in case there are <10 peers in existence. Therefore, we slow the walk down to a 5s/step.
             self.ipv8.add_strategy(community, RandomWalk(community, target_interval=5), 10)
+            self.ipv8.add_strategy(community, RandomChurn(community), -1)
             self.pex[payload.info_hash] = community
 
         # PEX announce
