@@ -2,10 +2,10 @@ import struct
 
 from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives import hashes
-from cryptography.hazmat.primitives.ciphers.aead import AESGCM
 from cryptography.hazmat.primitives.kdf.hkdf import HKDFExpand
 
 import libnacl
+from libnacl.aead import AEAD
 
 from ...keyvault.crypto import ECCrypto, LibNaCLPK
 
@@ -48,24 +48,15 @@ class TunnelCrypto(ECCrypto):
         return shared_secret
 
     def generate_session_keys(self, shared_secret):
-        hkdf = HKDFExpand(algorithm=hashes.SHA256(), backend=default_backend(), length=40, info=b"key_generation")
+        hkdf = HKDFExpand(algorithm=hashes.SHA256(), backend=default_backend(), length=72, info=b"key_generation")
         key = hkdf.derive(shared_secret)
 
-        kf = key[:16]
-        kb = key[16:32]
-        sf = key[32:36]
-        sb = key[36:40]
+        kf = key[:32]
+        kb = key[32:64]
+        sf = key[64:68]
+        sb = key[68:72]
         return [kf, kb, sf, sb, 1, 1]
 
-    def _build_iv(self, salt, salt_explicit):
-        assert isinstance(salt, (bytes, str)), type(salt)
-        assert isinstance(salt_explicit, int), type(salt_explicit)
-
-        if salt_explicit == 0:
-            raise CryptoException("salt_explicit wrapped")
-
-        return salt + str(salt_explicit).encode()
-
     def get_session_keys(self, keys, direction):
         # increment salt_explicit
         keys[direction + 4] += 1
@@ -73,15 +64,16 @@ class TunnelCrypto(ECCrypto):
 
     def encrypt_str(self, content, key, salt, salt_explicit):
         # return the encrypted content prepended with salt_explicit
-        aesgcm = AESGCM(key)
-        ciphertext = aesgcm.encrypt(self._build_iv(salt, salt_explicit), content, None)
+        aead = AEAD(key)
+        _, _, ciphertext = aead.encrypt(content, b'',
+                                        nonce=salt + struct.pack('!q', salt_explicit),
+                                        pack_nonce_aad=False)
         return struct.pack('!q', salt_explicit) + ciphertext
 
     def decrypt_str(self, content, key, salt):
-        # content contains the gcm tag and salt_explicit in plaintext
+        # content contains the tag and salt_explicit in plaintext
         if len(content) < 24:
             raise CryptoException("truncated content")
 
-        salt_explicit, = struct.unpack_from('!q', content)
-        aesgcm = AESGCM(key)
-        return aesgcm.decrypt(self._build_iv(salt, salt_explicit), content[8:], None)
+        aead = AEAD(key)
+        return aead.decrypt(salt + content, 0)
