@@ -17,8 +17,7 @@ else:
         from ipv8.attestation.wallet.community import AttestationCommunity
         from ipv8.bootstrapping.dispersy.bootstrapper import DispersyBootstrapper
         from ipv8.bootstrapping.udpbroadcast.bootstrapper import UDPBroadcastBootstrapper
-        from ipv8.keyvault.crypto import default_eccrypto
-        from ipv8.keyvault.private.m2crypto import M2CryptoSK
+        from ipv8.keyvault.crypto import default_eccrypto as crypto
         from ipv8.messaging.anonymization.community import TunnelCommunity
         from ipv8.messaging.anonymization.endpoint import TunnelEndpoint
         from ipv8.messaging.anonymization.hidden_services import HiddenTunnelCommunity
@@ -36,8 +35,7 @@ else:
         from .ipv8.attestation.wallet.community import AttestationCommunity
         from .ipv8.bootstrapping.dispersy.bootstrapper import DispersyBootstrapper
         from .ipv8.bootstrapping.udpbroadcast.bootstrapper import UDPBroadcastBootstrapper
-        from .ipv8.keyvault.crypto import default_eccrypto
-        from .ipv8.keyvault.private.m2crypto import M2CryptoSK
+        from .ipv8.keyvault.crypto import default_eccrypto as crypto
         from .ipv8.messaging.anonymization.community import TunnelCommunity
         from .ipv8.messaging.anonymization.endpoint import TunnelEndpoint
         from .ipv8.messaging.anonymization.hidden_services import HiddenTunnelCommunity
@@ -69,18 +67,31 @@ else:
         'UDPBroadcastBootstrapper': UDPBroadcastBootstrapper
     }
 
-    class IPv8(object):
+    class IPv8:
 
         def __init__(self, configuration, endpoint_override=None, enable_statistics=False, extra_communities=None):
             super(IPv8, self).__init__()
             self.configuration = configuration
 
+            # Setup logging
+            logging.basicConfig(**configuration['logger'])
+
             if endpoint_override:
                 self.endpoint = endpoint_override
             else:
-                self.endpoint = DispatcherEndpoint(["UDPIPv4"],
-                                                   UDPIPv4={'port': configuration['port'],
-                                                            'ip': configuration['address']})
+                if 'address' in configuration or 'port' in configuration:
+                    logging.warning("Using deprecated 'address' and 'port' configuration! "
+                                    "Auto-porting your config to \"UDPIPv4\" interface configuration. "
+                                    "Switch your code to IPv8 configuration using 'interfaces' instead.")
+                    if 'interfaces' not in configuration:
+                        configuration['interfaces'] = []
+                    configuration['interfaces'].append({'interface': "UDPIPv4",
+                                                        'ip': configuration.get('address', "0.0.0.0"),
+                                                        'port': configuration.get('port', 8090)})
+                endpoint_specs = (spec.copy() for spec in configuration['interfaces'])
+                endpoint_args = {spec.pop('interface'): spec for spec in endpoint_specs}
+                self.endpoint = DispatcherEndpoint(list(endpoint_args.keys()), **endpoint_args)
+
             if enable_statistics:
                 self.endpoint = StatisticsEndpoint(self.endpoint)
             if any([overlay.get('initialize', {}).get('anonymize') for overlay in configuration['overlays']]):
@@ -93,30 +104,15 @@ else:
             for key_block in configuration['keys']:
                 if key_block['file'] and isfile(key_block['file']):
                     with open(key_block['file'], 'rb') as f:
-                        content = f.read()
-                        try:
-                            # IPv8 Standardized bin format
-                            self.keys[key_block['alias']] = Peer(default_eccrypto.key_from_private_bin(content))
-                        except ValueError:
-                            try:
-                                # Try old Tribler M2Crypto PEM format
-                                content = b64decode(content[31:-30].replace('\n', ''))
-                                peer = Peer(M2CryptoSK(keystring=content))
-                                peer.mid  # This will error out if the keystring is not M2Crypto
-                                self.keys[key_block['alias']] = peer
-                            except Exception:
-                                # Try old LibNacl format
-                                content = "LibNaCLSK:" + content
-                                self.keys[key_block['alias']] = Peer(default_eccrypto.key_from_private_bin(content))
+                        self.keys[key_block['alias']] = Peer(crypto.key_from_private_bin(f.read()))
                 else:
-                    self.keys[key_block['alias']] = Peer(default_eccrypto.generate_key(key_block['generation']))
+                    self.keys[key_block['alias']] = Peer(crypto.key_from_private_bin(b64decode(key_block['bin']))
+                                                         if 'bin' in key_block else
+                                                         crypto.generate_key(key_block['generation']))
                     if key_block['file']:
                         with open(key_block['file'], 'wb') as f:
                             f.write(self.keys[key_block['alias']].key.key_to_bin())
 
-            # Setup logging
-            logging.basicConfig(**configuration['logger'])
-
             self.overlay_lock = RLock()
             self.strategies = []
             self.overlays = []
@@ -199,7 +195,11 @@ else:
             return (o for o in self.overlays if isinstance(o, overlay_cls))
 
         async def produce_anonymized_endpoint(self):
-            base_endpoint = UDPEndpoint(port=0, ip=self.configuration['address'])
+            address = self.configuration.get('address', "0.0.0.0")
+            for spec in self.configuration.get('interfaces', []):
+                if spec['interface'] == "UDPIPv4":
+                    address = spec['ip']
+            base_endpoint = UDPEndpoint(port=0, ip=address)
             await base_endpoint.open()
             return TunnelEndpoint(base_endpoint)
 
